@@ -42,9 +42,10 @@ def build_index(dirbook) :
     content +=("<head>\n")
     content +=("  <meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">\n")
     content +=("  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"/>\n")
+    content +=("  <meta http-equiv=\"refresh\" content=\"120\"/>\n")
     content +=("  <title>Novels</title>\n")
     content +=("</head>\n")
-    content +=("<body style=\"background-color: #212121;color: #B5B5B5;\">\n")
+    content +=("<body style=\"background-color: #B5B5B5;color: #212121;\">\n")
     content += '<div align="center" style="vertical-align:bottom">' + "\n"
     content +=("<table border=1 style=\"border-collapse:collapse;\">\n")
     tmstr = strftime("%H:%M",localtime())
@@ -275,6 +276,8 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         rtext += ps.replace("prevpg",prevpg).replace("nextpg",nextpg)
         rtext += "</head>\n"
         rtext += "<body style=\"background-color: #212121;color: #B5B5B5;\">\n"
+        rtext += "<a href=\"{}\">Novels Home</a><br/>\n".format("https://walkerever.com/novels")
+        rtext += "<br/>\n"*2
         rtext += "<a href=\"index.html\">INDEX of {}</a>\n".format(title)
         rtext += "<br/>\n"*2
         rtext += "<a href=\"{}\">PREV CHAPTER</a>\n".format(prevpg)
@@ -293,6 +296,8 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
         rtext += "<br/>\n"*2
         rtext += "<a href=\"{}\">ORIGIN_SOURCE</a><br/>\n".format(url)
         rtext += "<br/>\n"*2
+        rtext += "<a href=\"{}\">Novels Home</a><br/>\n".format("https://walkerever.com/novels")
+        rtext += "<br/>\n"*2
         rtext += "</body>\n"
         rtext += "</html>\n"
         with open(os.path.join(tgtdir,title, cname),"w",encoding="UTF-8") as f :
@@ -310,7 +315,9 @@ def adhoc_fetch(title,page,limit=10,tgtdir=os.getcwd(),debug=False,force=0,root=
                     report += ", {}".format(chapter)
             downloaded.add(cname)
         cdone+=1
-        time.sleep(0.5+float(random.choice([i for i in range(30)])/10.0))
+        tm = 2+float(random.choice([i for i in range(50)])/10.0)
+        print("# sleep : {}".format(tm), file=sys.stderr, flush=True)
+        time.sleep(tm)
     report = report.rstrip(",")
     return report
 
@@ -319,7 +326,7 @@ def batch_fetch(cfgfile,num=10,debug=False,force=0,exlist=None) :
     report = "\n"
     with open(cfgfile,"r",encoding="UTF-8") as f :
         thefirst = True
-        seconds_wait = 5
+        seconds_wait = 10
         for ln in f.readlines() :
             if not ln or ln.startswith("#") :
                 continue
@@ -346,9 +353,9 @@ def batch_fetch(cfgfile,num=10,debug=False,force=0,exlist=None) :
                     rpt = adhoc_fetch(title,page,num,tgtdir,debug,force,root,exlist) + "\n"
                     report += rpt
                     if not rpt or not re.search(r"\S+",rpt) or re.search(r"No update",rpt,re.IGNORECASE) :
-                        seconds_wait = 5
+                        seconds_wait = 10 
                     else :
-                        seconds_wait = 10+random.choice([i for i in range(30)])
+                        seconds_wait = 30+random.choice([i for i in range(60)])
                 except :
                     traceback.print_exc()
                     seonds_wait = 20
